[4.1] 2a7fbd5 Typos and grammar

Lasse Karstensen lkarsten at varnish-software.com
Thu Jan 14 15:15:05 CET 2016


commit 2a7fbd5014340b3b4682f94d4d6bb0ebdc5de884
Author: Federico G. Schwindt <fgsch at lodoss.net>
Date:   Wed Nov 11 13:36:07 2015 +0000

    Typos and grammar
    
    Fixes #1814 and more.

diff --git a/bin/varnishadm/varnishadm.c b/bin/varnishadm/varnishadm.c
index 1f02da9..12650b2 100644
--- a/bin/varnishadm/varnishadm.c
+++ b/bin/varnishadm/varnishadm.c
@@ -382,7 +382,7 @@ usage(void)
 	fprintf(stderr,
 	    "usage: varnishadm [-n ident] [-t timeout] [-S secretfile] "
 	    "-T [address]:port command [...]\n");
-	fprintf(stderr, "\t-n is mutually exlusive with -S and -T\n");
+	fprintf(stderr, "\t-n is mutually exclusive with -S and -T\n");
 	exit(1);
 }
 
diff --git a/bin/varnishd/cache/cache_esi_parse.c b/bin/varnishd/cache/cache_esi_parse.c
index aa31aa4..76591d0 100644
--- a/bin/varnishd/cache/cache_esi_parse.c
+++ b/bin/varnishd/cache/cache_esi_parse.c
@@ -1087,7 +1087,7 @@ VEP_Finish(struct vep_state *vep)
 		lcb = vep->cb(vep->vc, vep->cb_priv, 0, VGZ_ALIGN);
 		vep_emit_common(vep, lcb - vep->o_last, vep->last_mark);
 	}
-	// NB: We don't acount for PAD+SUM+LEN in gzip'ed objects
+	// NB: We don't account for PAD+SUM+LEN in gzip'ed objects
 	(void)vep->cb(vep->vc, vep->cb_priv, 0, VGZ_FINISH);
 
 	AZ(VSB_finish(vep->vsb));
diff --git a/bin/varnishd/cache/cache_fetch.c b/bin/varnishd/cache/cache_fetch.c
index 8e0a70b..662048d 100644
--- a/bin/varnishd/cache/cache_fetch.c
+++ b/bin/varnishd/cache/cache_fetch.c
@@ -578,7 +578,7 @@ vbf_stp_fetch(struct worker *wrk, struct busyobj *bo)
 	    (bo->do_gunzip && !bo->is_gzip))
 		bo->do_gunzip = 0;
 
-	/* We wont gzip unless it is non-empty and ungziped */
+	/* We wont gzip unless it is non-empty and ungzip'ed */
 	if (bo->htc->body_status == BS_NONE ||
 	    bo->htc->content_length == 0 ||
 	    (bo->do_gzip && !bo->is_gunzip))
diff --git a/bin/varnishd/cache/cache_wrk.c b/bin/varnishd/cache/cache_wrk.c
index 86e0b92..7b774b1 100644
--- a/bin/varnishd/cache/cache_wrk.c
+++ b/bin/varnishd/cache/cache_wrk.c
@@ -44,7 +44,7 @@
 static void Pool_Work_Thread(struct pool *pp, struct worker *wrk);
 
 /*--------------------------------------------------------------------
- * Create and starte a back-ground thread which as its own worker and
+ * Create and start a back-ground thread which as its own worker and
  * session data structures;
  */
 
diff --git a/bin/varnishd/common/common.h b/bin/varnishd/common/common.h
index 7b2c371..da489fc 100644
--- a/bin/varnishd/common/common.h
+++ b/bin/varnishd/common/common.h
@@ -127,7 +127,7 @@ void VSM_common_ageupdate(const struct vsm_sc *sc);
 #define RUP2(x, y)  (((x)+((y)-1))&(~((uintptr_t)(y)-1UL))) /* PWR2(y) true */
 
 /*--------------------------------------------------------------------
- * Pointer aligment magic
+ * Pointer alignment magic
  */
 
 #if defined(__sparc__)
diff --git a/bin/varnishd/mgt/mgt_jail_solaris.c b/bin/varnishd/mgt/mgt_jail_solaris.c
index bb90598..2dd9322 100644
--- a/bin/varnishd/mgt/mgt_jail_solaris.c
+++ b/bin/varnishd/mgt/mgt_jail_solaris.c
@@ -27,8 +27,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * "Jailing" *1) child processes on Solaris and Solaris-derivates *2)
- * ==================================================================
+ * "Jailing" *1) child processes on Solaris and Solaris-derivatives *2)
+ * ====================================================================
  *
  * *1) The name is motivated by the availability of the -j command line
  *     option. Jailing Varnish is not to be confused with BSD Jails or
diff --git a/bin/varnishd/proxy/cache_proxy_proto.c b/bin/varnishd/proxy/cache_proxy_proto.c
index 6f64f3a..4799e4b 100644
--- a/bin/varnishd/proxy/cache_proxy_proto.c
+++ b/bin/varnishd/proxy/cache_proxy_proto.c
@@ -344,7 +344,7 @@ VPX_Proto_Sess(struct worker *wrk, void *priv)
 	CAST_OBJ_NOTNULL(req, priv, REQ_MAGIC);
 	sp = req->sp;
 
-	/* Per specifiction */
+	/* Per specification */
 	assert(sizeof vpx1_sig == 5);
 	assert(sizeof vpx2_sig == 12);
 
diff --git a/bin/varnishd/storage/storage_malloc.c b/bin/varnishd/storage/storage_malloc.c
index 445afab..ce6b0c2 100644
--- a/bin/varnishd/storage/storage_malloc.c
+++ b/bin/varnishd/storage/storage_malloc.c
@@ -86,7 +86,7 @@ sma_alloc(const struct stevedore *st, size_t size)
 	 * Do not collaps the sma allocation with sma->s.ptr: it is not
 	 * a good idea.  Not only would it make ->trim impossible,
 	 * performance-wise it would be a catastropy with chunksized
-	 * allocations growing another full page, just to accomodate the sma.
+	 * allocations growing another full page, just to accommodate the sma.
 	 */
 
 	p = malloc(size);
diff --git a/bin/varnishtest/tests.disabled/r01576.vtc b/bin/varnishtest/tests.disabled/r01576.vtc
index b0fdb9f..9ed5f7a 100644
--- a/bin/varnishtest/tests.disabled/r01576.vtc
+++ b/bin/varnishtest/tests.disabled/r01576.vtc
@@ -19,7 +19,7 @@ server s1 {
 # varnish v1 -arg "-p pcre_match_limit=1000"
 # varnish v1 -arg "-p pcre_match_limit_recursion=89"
 
-# Approximate formua for FreeBSD/amd64:
+# Approximate formula for FreeBSD/amd64:
 #	pcre_match_limit_recursion = thread_pool_stack * 2 - 9
 
 varnish v1 -vcl+backend {
diff --git a/config.phk b/config.phk
index 760ea22..906cbff 100644
--- a/config.phk
+++ b/config.phk
@@ -3,7 +3,7 @@
 set -e
 
 #######################################################################
-# Adminstrative settings
+# Administrative settings
 
 ADM_PROJECT=varnish
 ADM_VERSION=trunk
diff --git a/doc/changes.rst b/doc/changes.rst
index 6016ddc..04aed34 100644
--- a/doc/changes.rst
+++ b/doc/changes.rst
@@ -1557,7 +1557,7 @@ Changes from 2.1.1 to 2.1.2
 varnishd
 --------
 
--  When adding Range support for 2.1.1, we accidentially introduced a
+-  When adding Range support for 2.1.1, we accidentally introduced a
    bug which would append garbage to objects larger than the chunk size,
    by default 128k. Browsers would do the right thing due to
    Content-Length, but some load balancers would get very confused.
@@ -1964,7 +1964,7 @@ varnishd
    send out a zero-sized chunk which signifies end-of-transmission. We
    now ignore zero-sized chunks.
 
--  We accidentially slept for far too long when we reached the maximum
+-  We accidentally slept for far too long when we reached the maximum
    number of open file descriptors. This has been corrected and
    accept\_fd\_holdoff now works correctly.
 
@@ -2196,7 +2196,7 @@ varnishd
 -  Solaris is now supported.
 
 -  There is now a regsuball function, which works like regsub except it
-   replaces all occurences of the regex, not just the first.
+   replaces all occurrences of the regex, not just the first.
 
 -  Backend and director declarations can have a .connect\_timeout
    parameter, which tells us how long to wait for a successful
diff --git a/doc/sphinx/phk/autocrap.rst b/doc/sphinx/phk/autocrap.rst
index 308dde3..e97ac4c 100644
--- a/doc/sphinx/phk/autocrap.rst
+++ b/doc/sphinx/phk/autocrap.rst
@@ -55,7 +55,7 @@ different dialects to just a handful: Linux, \*BSD, Solaris and AIX
 and the autocrap tools have become part of the portability problem,
 rather than part of the solution.
 
-Amongst the silly activites of the autocrap generated configure script
+Amongst the silly activities of the autocrap generated configure script
 in Varnish are:
 
 * Looks for ANSI-C header files (show me a system later
diff --git a/doc/sphinx/phk/brinch-hansens-arrows.rst b/doc/sphinx/phk/brinch-hansens-arrows.rst
index cba1f44..f4299b5 100644
--- a/doc/sphinx/phk/brinch-hansens-arrows.rst
+++ b/doc/sphinx/phk/brinch-hansens-arrows.rst
@@ -16,7 +16,7 @@ lock B trying to get lock A.
 
 Brinch-Hansen did a lot of both theoretical and practical work in the
 area of multiprogramming and being both good at it and one of the
-pioneers, he was awardede the ACM Turing Prize for it.
+pioneers, he was awarded the ACM Turing Prize for it.
 
 You can read more about him here:
 `Brinch-Hansen Archive <http://brinch-hansen.net/>`_
@@ -26,7 +26,7 @@ that a given multiprogramming system was free of deadlocks:  Draw
 the locking order and make sure all the arrows point to the right.
 
 When we started working with multi-core systems in FreeBSD, we were
-sure to have deadlocks in our future, and we adobted and expanded
+sure to have deadlocks in our future, and we adopted and expanded
 a facility called "WITNESS" originally written for BSDI, which
 keeps an eye on Brinch-Hansens arrows in real time.
 
diff --git a/doc/sphinx/phk/dough.rst b/doc/sphinx/phk/dough.rst
index b629e8b..aef598b 100644
--- a/doc/sphinx/phk/dough.rst
+++ b/doc/sphinx/phk/dough.rst
@@ -184,7 +184,7 @@ the message to other communities, that Free and Open Source Software
 does not materialize out of empty space, it is written by people.
 
 People who love what we do, which is why I'm sitting here,
-way past midnight on a friday evening, writing this phamplet.
+way past midnight on a friday evening, writing this pamphlet.
 
 But software *is* written by people, real people with kids, cars,
 mortgages, leaky roofs, sick pets, infirm parents and all other
diff --git a/doc/sphinx/phk/http20.rst b/doc/sphinx/phk/http20.rst
index 9860cab..c2b4d17 100644
--- a/doc/sphinx/phk/http20.rst
+++ b/doc/sphinx/phk/http20.rst
@@ -59,7 +59,7 @@ What if they made a new protocol, and nobody used it ?
 We have learned, painfully, that an IPv6 which is only marginally
 better than IPv4 and which offers no tangible benefit for the people
 who have the cost/trouble of the upgrade, does not penetrate the
-network on its own, and barely even on goverments mandate.
+network on its own, and barely even on governments mandate.
 
 We have also learned that a protocol which delivers the goods can
 replace all competition in virtually no time.
@@ -86,16 +86,16 @@ Most notably HTTP/1.1 lacks a working session/endpoint-identity
 facility, a shortcoming which people have pasted over with the
 ill-conceived Cookie hack.
 
-Cookies are, as the EU commision correctly noted, fundamentally
+Cookies are, as the EU commission correctly noted, fundamentally
 flawed, because they store potentially sensitive information on
 whatever computer the user happens to use, and as a result of various
 abuses and incompetences, EU felt compelled to legislate a "notice
 and announce" policy for HTTP-cookies.
 
 But it doesn't stop there:  The information stored in cookies have
-potentialiiy very high value for the HTTP server, and because the
+potentially very high value for the HTTP server, and because the
 server has no control over the integrity of the storage, we are now
-seing cookies being crypto-signed, to prevent forgeries.
+seeing cookies being crypto-signed, to prevent forgeries.
 
 The term "bass ackwards" comes to mind.
 
@@ -124,7 +124,7 @@ new layer of complexity without removing any of the old complexity
 from the protocol.
 
 My conclusion is that HTTP/2.0 is really just a grandiose name for
-HTTP/1.2:  An attempt to smoothe out some sharp corners, to save a
+HTTP/1.2:  An attempt to smooth out some sharp corners, to save a
 bit of bandwidth, but not get anywhere near all the architectural
 problems of HTTP/1.1 and to preserve faithfully its heritage of
 badly thought out sedimentary hacks.
@@ -151,7 +151,7 @@ mobs and special event traffic spikes.
 
 In the time frame where HTTP/2.0 will become standardized, HTTP
 routers will routinely deal with 40Gbit/s traffic and people will
-start to arcitect for 1Tbit/s traffic.
+start to architect for 1Tbit/s traffic.
 
 HTTP routers are usually only interested in a small part of the
 HTTP request and barely in the response at all, usually only the
@@ -217,7 +217,7 @@ expend resources, and foresee a lot of complexity in implementing
 the server side to mitigate and deflect malicious traffic.
 
 Server Push breaks the HTTP transaction model, and opens a pile of
-cans of security and privacy issues, which whould not be sneaked
+cans of security and privacy issues, which would not be sneaked
 in during the design of a transport-encoding for HTTP/1+ traffic,
 but rather be standardized as an independent and well analysed
 extension to HTTP in general.
@@ -228,7 +228,7 @@ HTTP Speed+Mobility
 
 Is really just SPDY with WebSockets underneath.
 
-I'm really not sure I see any benefit to that, execept that the
+I'm really not sure I see any benefit to that, except that the
 encoding chosen is marginally more efficient to implement in
 hardware than SPDY.
 
@@ -268,7 +268,7 @@ Overall, I don't see any of the three proposals offer anything that
 will make the majority of web-sites go "Ohh we've been waiting for
 that!"
 
-Bigger sites will be entised by small bandwidth savings, but the
+Bigger sites will be enticed by small bandwidth savings, but the
 majority of the HTTP users will see scant or no net positive benefit
 if one or more of these three proposals were to become HTTP/2.0
 
diff --git a/doc/sphinx/phk/ssl_again.rst b/doc/sphinx/phk/ssl_again.rst
index ba4ecf1..31b6efe 100644
--- a/doc/sphinx/phk/ssl_again.rst
+++ b/doc/sphinx/phk/ssl_again.rst
@@ -54,7 +54,7 @@ The next morning `CloudFlare announced the very same thing`_:
 
 .. _CloudFlare announced the very same thing: https://blog.cloudflare.com/keyless-ssl-the-nitty-gritty-technical-details/
 
-This could conceiveably be a way to terminate TLS/SSL in the Varnish-worker
+This could conceivably be a way to terminate TLS/SSL in the Varnish-worker
 process, while keeping the most valuable crypto-bits away from it.
 
 But it's still a bad idea
@@ -117,7 +117,7 @@ I'm not too thrilled about the "SSL Everywhere" idea, for a large
 number of reasons.
 
 The most obvious example is that you don't want to bog down your
-countrys civil defence agency with SSL/TLS protocol negotiations,
+country's civil defence agency with SSL/TLS protocol negotiations,
 if their website is being deluged by people trying to survive a
 natural disaster.
 
diff --git a/doc/sphinx/phk/thetoolsweworkwith.rst b/doc/sphinx/phk/thetoolsweworkwith.rst
index 2631c73..4ee56db 100644
--- a/doc/sphinx/phk/thetoolsweworkwith.rst
+++ b/doc/sphinx/phk/thetoolsweworkwith.rst
@@ -153,7 +153,7 @@ duration for the call, because then it doesn't matter what time
 it is, only how long time has transpired.
 
 Ohh, and setting the stack-size for a new thread ?
-That is appearantly "too dangerous" so there is no argument in the
+That is apparently "too dangerous" so there is no argument in the
 C1X API for doing so, a clear step backwards from pthreads.
 
 But guess what:  Thread stacks are like T-shirts:  There is no "one
@@ -177,7 +177,7 @@ compiler can understand and use to issue warnings.
 Heck, even a simple basic object facility would be good addition,
 now that C++ have become this huge bloated monster language.
 
-But none of that is appearantly as important as <stdnoreturn.h>
+But none of that is apparently as important as <stdnoreturn.h>
 and a new, crippled and therefore useless thread API.
 
 The neat thing about the C language, and the one feature that made
diff --git a/doc/sphinx/reference/vcl.rst b/doc/sphinx/reference/vcl.rst
index cd942e6..c982cb9 100644
--- a/doc/sphinx/reference/vcl.rst
+++ b/doc/sphinx/reference/vcl.rst
@@ -59,9 +59,9 @@ Conditionals
 ------------
 
 VCL has *if* and *else* statements. Nested logic can be implemented
-with the *elseif* statement. (*elsif*/*elif*/*else if* is equivalent.)
+with the *elseif* statement (*elsif*/*elif*/*else if* are equivalent).
 
-Note that are no loops or iterators of any kind in VCL.
+Note that there are no loops or iterators of any kind in VCL.
 
 
 Strings, booleans, time, duration and integers
diff --git a/doc/sphinx/users-guide/vcl.rst b/doc/sphinx/users-guide/vcl.rst
index 3528e7b..0458704 100644
--- a/doc/sphinx/users-guide/vcl.rst
+++ b/doc/sphinx/users-guide/vcl.rst
@@ -13,7 +13,7 @@ switches. We have instead chosen to use a domain specific language called VCL fo
 
 Every inbound request flows through Varnish and you can influence how
 the request is being handled by altering the VCL code. You can direct
-certain requests to certains backends, you can alter the requests and
+certain requests to particular backends, you can alter the requests and
 the responses or have Varnish take various actions depending on
 arbitrary properties of the request or the response. This makes
 Varnish an extremely powerful HTTP processor, not just for caching.
diff --git a/include/tbl/http_headers.h b/include/tbl/http_headers.h
index 91ea213..0d973c7 100644
--- a/include/tbl/http_headers.h
+++ b/include/tbl/http_headers.h
@@ -86,7 +86,7 @@ H("If-Match",		H_If_Match,		  F  )	// 2616 14.24
 H("If-Modified-Since",	H_If_Modified_Since,	  F  )	// 2616 14.25
 H("If-None-Match",	H_If_None_Match,	  F  )	// 2616 14.26
 H("If-Range",		H_If_Range,		  F  )	// 2616 14.27
-H("If-Unmodified-Since",H_If_Unmodifed_Since,	  F  )	// 2616 14.28
+H("If-Unmodified-Since",H_If_Unmodified_Since,	  F  )	// 2616 14.28
 H("Last-Modified",	H_Last_Modified,	0    )	// 2616 14.29
 H("Location",		H_Location,		0    )	// 2616 14.30
 H("Max-Forwards",	H_Max_Forwards,		0    )	// 2616 14.31
diff --git a/include/vapi/vsl.h b/include/vapi/vsl.h
index 599c654..c6afb2f 100644
--- a/include/vapi/vsl.h
+++ b/include/vapi/vsl.h
@@ -215,7 +215,7 @@ int VSL_List2Tags(const char *list, int l, VSL_tagfind_f *func, void *priv);
 	 *   func: The function to call (can be NULL)
 	 *   priv: An argument that will be passed to func.
 	 *
-	 * Return valus:
+	 * Return values:
 	 *     >0: Number of times func was called for matching tags.
 	 *     -1: No tag matches for list element
 	 *     -2: Multiple tags match non-glob list element
diff --git a/lib/libvarnish/vsub.c b/lib/libvarnish/vsub.c
index cf71c26..4e3067a 100644
--- a/lib/libvarnish/vsub.c
+++ b/lib/libvarnish/vsub.c
@@ -106,7 +106,7 @@ VSUB_run(struct vsb *sb, vsub_func_f *func, void *priv, const char *name,
 		/*
 		 * func should either exec or exit, so getting here should be
 		 * treated like an assertion failure - except that we don't know
-		 * if it's safe to trigger an acutal assertion
+		 * if it's safe to trigger an actual assertion
 		 */
 		_exit(4);
 	}
diff --git a/lib/libvarnish/vtcp.c b/lib/libvarnish/vtcp.c
index 3992555..cb4d3c4 100644
--- a/lib/libvarnish/vtcp.c
+++ b/lib/libvarnish/vtcp.c
@@ -545,7 +545,7 @@ VTCP_Check(int a)
 		return (1);
 #if (defined (__SVR4) && defined (__sun)) || defined (__NetBSD__)
 	/*
-	 * Solaris returns EINVAL if the other end unexepectedly reset the
+	 * Solaris returns EINVAL if the other end unexpectedly reset the
 	 * connection.
 	 * This is a bug in Solaris and documented behaviour on NetBSD.
 	 */
diff --git a/lib/libvcc/vcc_compile.c b/lib/libvcc/vcc_compile.c
index 4bd7821..e79597f 100644
--- a/lib/libvcc/vcc_compile.c
+++ b/lib/libvcc/vcc_compile.c
@@ -30,7 +30,7 @@
 /*
  * XXX:
  *	Better error messages, throughout.
- *	>It also accured to me that we could link the errors to the error
+ *	>It also occurred to me that we could link the errors to the error
  *	>documentation.
  *	>
  *	>Unreferenced  function 'request_policy', first mention is



More information about the varnish-commit mailing list
diff --git a/lib/libvarnish/vfil.c b/lib/libvarnish/vfil.c
index 19928ff..4b57d01 100644
--- a/lib/libvarnish/vfil.c
+++ b/lib/libvarnish/vfil.c
@@ -158,7 +158,7 @@ VFIL_fsinfo(int fd, unsigned *pbs, uintmax_t *psize, uintmax_t *pspace)
 	return (0);
 }
 
 /* Make sure that the file system can accomodate the file of the given
  * size. Will use fallocate if available. If fallocate is not available
  * and insist is true, it will write size zero bytes.
  *
@@ -191,7 +191,7 @@ VFIL_allocate(int fd, off_t size, int insist)
 		   the already allocated blocks of the file into
 		   account. This will cause fallocate to report ENOSPC
 		   when called on an existing fully allocated file unless
-		   the filesystem has enough free space to accomodate the
+		   the filesystem has enough free space to accommodate the
 		   complete new file size. Because of this we enable
 		   fallocate only on filesystems that are known to work as
 		   we expect. */
@@ -158,7 +158,7 @@ VFIL_fsinfo(int fd, unsigned *pbs, uintmax_t *psize, uintmax_t *pspace)
 }
 
-/* Make sure that the file system can accomodate the file of the given
+/* Make sure that the file system can accommodate the file of the given
  * size. Will use fallocate if available. If fallocate is not available
  * and insist is true, it will write size zero bytes.